@@ -5,7 +5,7 @@ import fuzzyCompare
 import pandas as pd
 
 
-def diffReport(path_file_a, path_file_b, path_file_output='', html_return=True, partial_ratio="tokenSortRatio"):
+def diffReport(path_file_a, path_file_b, path_file_output='', html_return=True, partial_ratio="tokenSortRatio", exlude_analytics = [] ):
     """
 
     :param path_file_a: Path for the File A to be compared.
@@ -13,6 +13,7 @@ def diffReport(path_file_a, path_file_b, path_file_output='', html_return=True,
     :param path_file_output: Path of the directory where the output HTML file needs to be saved. (Default: 'Output/')
     :param html_return: Boolean to select if the function returns HTML of the report. (True by default)
     :param partial_ratio: Partial Ratio Type, Accepted Values are ("Ratio", "qRatio", "wRatio", "ratio_2", "tokenSetRatio", "tokenSortRatio", "partialTokenSortRatio", "default")
+    :param exlude_analytics: List of character or strings to exclude from the pdf during analysis.
     :return: HTML for the report if html_return is set to True.  If set to false, it will return the DataFrame.
 
     Function takes two PDF file paths as input, and generates a difference report with the lines that are different
@@ -41,8 +42,14 @@ def diffReport(path_file_a, path_file_b, path_file_output='', html_return=True,
     text_lines_b = text_extract_b.split('\n')
 
     junk = ['', ' ', '   ', '\t', '                                                                                                                 ']
+    junk = junk + exlude_analytics
+
     text_lines_a = [x for x in text_lines_a if x not in junk]
     text_lines_b = [x for x in text_lines_b if x not in junk]
+    for exclusion in exlude_analytics:
+        text_lines_a = [x.replace(exclusion,'') for x in text_lines_a]
+        text_lines_b = [x.replace(exclusion, '') for x in text_lines_b]
+
 
     df = pd.DataFrame(columns=['File1', 'File2', 'Ratio', 'Partial Ratio'])
     count = 0
@@ -132,6 +139,6 @@ def html_output(df, path_file_output):
 
 
 if __name__ == '__main__':
-    x = diffReport("Example/Input/Default.pdf", "Example/Input/Default2.pdf", html_return=True)
+    x = diffReport("Example/Input/Default.pdf", "Example/Input/Default2.pdf", html_return=True, exlude_analytics=['to','with','function','changes'])
 
     # print(x)
